from setuptools import setup, find_packages
with open("README.md","r",encoding="utf-8") as fh:
    long_description = fh.read()
setup(
    name = "manini",
    version = "0.0.6",
    description = "An user-friendly plugin that enables to annotate images from a pre-trained model (segmentation, classification, detection) given by an user.",
    long_description = long_description,
    long_description_content_type = "text/markdown",
    url = "https://github.com/hereariim/manini",
    packages=find_packages(),
    author = "Herearii Metuarea",
    author_email = "herearii.metuarea@gmail.com",
    license = "BSD-3-Clause",
    license_files = "LICENSE",
    classifiers =[
        "Development Status :: 2 - Pre-Alpha",
        "Framework :: napari",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: BSD License",
        "Operating System :: OS Independent",
        "Programming Language :: Python",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3 :: Only",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Topic :: Scientific/Engineering :: Image Processing",
    ],
install_requires = [
    "numpy",
    "magicgui",
    "qtpy",
    "napari",
    "magicgui",
    "scikit-image",
    "numpy",
    "pandas",
    "opencv-python-headless",
    "tensorflow",
    "PyQt5"
],
python_requires = ">=3.8",
)


from qtpy.QtWidgets import QTableWidgetItem, QApplication, QWidget, QTableWidget, QComboBox, QVBoxLayout
import sys

class comboCompanies(QComboBox):
    def __init__(self,parent,LABEL_CATEGORY):
        super().__init__(parent)
        self.setStyleSheet('font-size: 15px')
        self.addItems(LABEL_CATEGORY)
        self.currentIndexChanged.connect(self.getComboValue)
        
    def getComboValue(self):
        print(self.currentText())
        
class TableWidget(QTableWidget):
    def __init__(self,df,LABEL_CATEGORY):
        super().__init__(1,3)
        
        self.setHorizontalHeaderLabels(['image','prediction','probability'])
        self.setColumnWidth(3,100)
        self.verticalHeader().setDefaultSectionSize(20)
        self.horizontalHeader().setDefaultSectionSize(150)
        self.les_classes = LABEL_CATEGORY
        self.dico_ = df
        self.load_data()
        
    def load_data(self):
        self.setRowCount(len(self.dico_['nom']))
        self.row=0
        for idx in range(len(self.dico_['nom'])):
            self.setItem(self.row,0,QTableWidgetItem(self.dico_['nom'][idx]))
            self.combo = comboCompanies(self,self.les_classes)
            self.setCellWidget(self.row,1,self.combo)
            self.combo.setCurrentText(self.dico_['prediction'][idx])
            self.setItem(self.row,2,QTableWidgetItem(str(self.dico_['prob'][idx])))
            self.row+=1